Searches for relevant data to make a datastamp.

make_stamp(
  script = NULL,
  time = NULL,
  system = NULL,
  session = NULL,
  files = NULL
)

Arguments

script

A logical to include the likely script of origin (default: TRUE).

time

A logical to include a timestamp in the datastamp (default: TRUE).

system

A logical to include system information (default: TRUE).

session

A logical to include session information (default: TRUE)

files

A character vector with file paths.

Value

A list of the class datastamp.

Details

When the script, time, system or session arguments are NULL the global options are searched for "datastamp.*" options, wherein the * is replaced by the argument names.

Examples

# Default stamp stamp <- make_stamp() # Not including some information: make_stamp(session = FALSE)
#> [datastamp] with script, time and system
# Alternatively: options("datastamp.session" = FALSE) make_stamp()
#> [datastamp] with script, time and system