A datastamp can contain relevant metadata about the circumstances an object was created in. This function generates a datastamp and attaches it to an object.

stamp(
  object,
  origin_files = NULL,
  script = NULL,
  time = NULL,
  system = NULL,
  session = NULL
)

Arguments

object

An R object to set a datastamp to.

origin_files

A character vector of file paths.

script

A logical to include the likely script of origin (default: TRUE).

time

A logical to include a timestamp in the datastamp (default: TRUE).

system

A logical to include system information (default: TRUE).

session

A logical to include session information (default: TRUE)

Value

The object input with a datastamp object in the attributes or metadata.

Details

For Bioconductor objects in the S4Vectors framework, the datastamp is stored in the metadata slot instead of the attributes.

See also

The setters and getters for datastamps. How to retrieve specific information from datastamped objects.

Examples

stamp(1:5)
#> [1] 1 2 3 4 5 #> attr(,"datastamp") #> [datastamp] with script, time and system