A datastamp can contain relevant metadata about the circumstances an object was created in. This function generates a datastamp and attaches it to an object.
stamp( object, origin_files = NULL, script = NULL, time = NULL, system = NULL, session = NULL )
| object | An R object to set a datastamp to. |
|---|---|
| origin_files | A |
| script | A |
| time | A |
| system | A |
| session | A |
The object input with a datastamp object in the attributes or
metadata.
For Bioconductor objects in the S4Vectors framework, the datastamp
is stored in the metadata slot instead of the attributes.
The setters and getters for datastamps. How to retrieve specific information from datastamped objects.
stamp(1:5)#> [1] 1 2 3 4 5 #> attr(,"datastamp") #> [datastamp] with script, time and system